@@ -18,7 +18,7 @@ echo ""
 ./abi-extract.pl -N it-IT      
 ./abi-extract.pl -N pt-BR 
 ./abi-extract.pl -N zh-TW 
-./abi-extract.pl -N cy-CY 
+./abi-extract.pl -N cy-GB 
 ./abi-extract.pl -N fi-FI 
 ./abi-extract.pl -N lt-LT 
 ./abi-extract.pl -N pt-PT 
@@ -28,4 +28,7 @@ echo ""
 ./abi-extract.pl -N ru-RU 
 ./abi-extract.pl -N bg-BG 
 ./abi-extract.pl -N tr-TR
+./abi-extract.pl -N ta-IN
 ./abi-extract.pl -N qu-BO
+./abi-extract.pl -N ast-ES
+./abi-extract.pl -N ku
