@@ -105,7 +105,14 @@ class ABI_EXPORT GR_Font
 	   NB: it is essential that this function is fast
 	*/
 	virtual bool doesGlyphExist(UT_UCS4Char g);
+//
+// UT_Rect of glyph in Logical units.
+// rec.left = bearing Left (distance from origin to start)
+// rec.width = width of the glyph
+// rec.top = distance from the origin to the top of the glyph
+// rec.height = total height of the glyph
 
+	virtual bool glyphBox(UT_UCS4Char g, UT_Rect & rec) const = 0;
 	static  bool s_doesGlyphExist(UT_UCS4Char g, void *instance)
 	{
 		UT_return_val_if_fail(instance, false);
@@ -375,12 +382,14 @@ class ABI_EXPORT GR_Graphics
 					   const char* pszFontWeight,
 					   const char* pszFontStretch,
 					   const char* pszFontSize);
-	static const char* findNearestFont(const char* pszFontFamily,
-									   const char* pszFontStyle,
-									   const char* pszFontVariant,
-									   const char* pszFontWeight,
-									   const char* pszFontStretch,
-									   const char* pszFontSize);
+	
+	virtual const char* findNearestFont(const char* pszFontFamily,
+										const char* pszFontStyle,
+										const char* pszFontVariant,
+										const char* pszFontWeight,
+										const char* pszFontStretch,
+										const char* pszFontSize)
+	                                         {return pszFontFamily;}
 
 	const char *      invertDimension(UT_Dimension, double) const;
 
@@ -487,7 +496,9 @@ class ABI_EXPORT GR_Graphics
 				   GR_CURSOR_VLINE_DRAG,
 				   GR_CURSOR_HLINE_DRAG,
 				   GR_CURSOR_CROSSHAIR,
-				   GR_CURSOR_DOWNARROW
+		                   GR_CURSOR_DOWNARROW,
+		                   GR_CURSOR_DRAGTEXT,
+		                   GR_CURSOR_COPYTEXT
 	} Cursor;
 
 	virtual void      setCursor(GR_Graphics::Cursor c) = 0;
