@@ -21,13 +21,31 @@
 #ifndef XAP_COCOATOOLBARICONS_H
 #define XAP_COCOATOOLBARICONS_H
 
-#import <AppKit/AppKit.h>
+#import <Cocoa/Cocoa.h>
 
 #include "ut_types.h"
+
 #include "xap_Toolbar_Icons.h"
 
 /*****************************************************************/
 
+@class XAP_CocoaToolbarButton;
+
+@protocol XAP_CocoaButtonController
+- (void)menuWillActivate:(NSMenu *)menu forButton:(XAP_CocoaToolbarButton *)button;
+@end
+
+@interface XAP_CocoaToolbarButton : NSButton
+{
+	NSMenu *	m_menu;
+	id <XAP_CocoaButtonController>	m_controller;
+}
+- (id)initWithFrame:(NSRect)frameRect;
+- (void)setMenu:(NSMenu *)menu withController:(id <XAP_CocoaButtonController>)controller;
+- (void)mouseDown:(NSEvent *)theEvent;
+- (void)drawRect:(NSRect)aRect;
+@end
+
 class AP_CocoaToolbar_Icons : public AP_Toolbar_Icons
 {
 public:
