@@ -101,8 +101,12 @@ LRESULT CALLBACK s_rebarWndProc( HWND hWnd, UINT uMessage, WPARAM wParam, LPARAM
 		
 		default:
 			break;		
-	}	
-	return CallWindowProc(s_oldRedBar, hWnd, uMessage, wParam, lParam);
+	}
+
+	if(UT_IsWinNT())
+		return CallWindowProcW(s_oldRedBar, hWnd, uMessage, wParam, lParam);
+	else
+		return CallWindowProc(s_oldRedBar, hWnd, uMessage, wParam, lParam);
 }
 
 
@@ -255,12 +259,12 @@ void XAP_Win32FrameImpl::_createTopLevelWindow(void)
 	}
 
 	// create a rebar container for all the toolbars
-	m_hwndRebar = CreateWindowEx(0L, REBARCLASSNAME, NULL,
-								 WS_VISIBLE | WS_BORDER | WS_CHILD | WS_CLIPCHILDREN |
-								 WS_CLIPSIBLINGS | CCS_NODIVIDER | CCS_NOPARENTALIGN |
-								 RBS_VARHEIGHT | RBS_BANDBORDERS,
-								 0, 0, 0, 0,
-								 m_hwndFrame, NULL, pWin32App->getInstance(), NULL);
+	m_hwndRebar = UT_CreateWindowEx(0L, REBARCLASSNAME, NULL,
+									WS_VISIBLE | WS_BORDER | WS_CHILD | WS_CLIPCHILDREN |
+									WS_CLIPSIBLINGS | CCS_NODIVIDER | CCS_NOPARENTALIGN |
+									RBS_VARHEIGHT | RBS_BANDBORDERS,
+									0, 0, 0, 0,
+									m_hwndFrame, NULL, pWin32App->getInstance(), NULL);
 	UT_ASSERT(m_hwndRebar);
 	
 	/* override the window procedure*/
@@ -928,7 +932,7 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 					IEGraphicFileType iegft = IEGFT_Unknown;					
 					IE_ImpGraphic *pIEG;
 					FG_Graphic* pFG;
-					UT_Error errorCode;
+					UT_Error errorCode = UT_ERROR;
 
 					/*
 						The user may be dropping any kind of file
@@ -940,26 +944,16 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 					if(errorCode == UT_OK)
 					{						
 						errorCode = pIEG->importGraphic(szFileName, &pFG);
-						if(errorCode != UT_OK || !pFG)
-						{
-							s_CouldNotLoadFileMessage(f, szFileName, errorCode);							
-							DELETEP(pIEG);
-							return 0;
-						}
 
-						DELETEP(pIEG);					
-
-						errorCode = pView->cmdInsertGraphic(pFG);
-						if (errorCode != UT_OK)
+						DELETEP(pIEG);
+						if(errorCode == UT_OK && pFG)
 						{
-							s_CouldNotLoadFileMessage(f, szFileName, errorCode);							
-							DELETEP(pFG);
-							return 0;
+						  errorCode = pView->cmdInsertGraphic(pFG);
+						  DELETEP(pFG);
 						}
-						
-						DELETEP(pFG);
 					  }
-					else
+
+					if (errorCode != UT_OK)
 					{	
 						// Check if the current document is empty.
 						if (f->isDirty() || f->getFilename() ||
@@ -968,8 +962,9 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 							pNewFrame = pApp->newFrame();
 							if (pNewFrame == NULL)
 							{
-								f->setStatusMessage("Could not open another window");
-								return 0;
+							  errorCode = UT_ERROR;
+							  f->setStatusMessage("Could not open another window");
+							  return 0;
 							}
 						}
 						else
@@ -977,18 +972,22 @@ LRESULT CALLBACK XAP_Win32FrameImpl::_FrameWndProc(HWND hwnd, UINT iMsg, WPARAM
 							pNewFrame = f;
 						}
 
-						UT_Error error = pNewFrame->loadDocument(szFileName, IEFT_Unknown);
-						if (error != UT_OK)
+						errorCode = pNewFrame->loadDocument(szFileName, IEFT_Unknown);
+						if (errorCode != UT_OK)
 						{
 							if (f != pNewFrame)
 								pNewFrame->close();
-							s_CouldNotLoadFileMessage(f, szFileName, error);
 						}
 						else
 						{
 							pNewFrame->show();
 						}
 					  }
+
+					if (errorCode != UT_OK)
+					  {
+					    s_CouldNotLoadFileMessage(f, szFileName, errorCode);
+					  }
 				}
 				else
 				{
