@@ -34,7 +34,7 @@
 #include "ut_assert.h"
 #include "ut_path.h"
 
-#if defined(XP_UNIX_TARGET_GTK) || (defined(__APPLE__) && defined(__MACH__)) || defined(WIN32) || defined(__QNXNTO__)
+//#if defined(XP_UNIX_TARGET_GTK) || (defined(__APPLE__) && defined(__MACH__)) || defined(WIN32) || defined(__QNXNTO__)
 
 /*** Also look at xap_Frame.cpp, half the XAP_FrameImpl seems to be there!!! ***/
 
@@ -70,7 +70,11 @@ XAP_FrameImpl::~XAP_FrameImpl(void)
 	FREEP(m_szToolbarLabelSetName);
 	FREEP(m_szToolbarAppearance);
 	UT_VECTOR_PURGEALL(EV_Toolbar *, m_vecToolbars);
+}
 
+void XAP_FrameImpl::notifyViewChanged(AV_View * pView)
+{
+	// called from XAP_Frame::setView(pView)
 }
 
 UT_RGBColor XAP_FrameImpl::getColorSelBackground () const
@@ -83,72 +87,6 @@ UT_RGBColor XAP_FrameImpl::getColorSelForeground () const
 	return UT_RGBColor(255, 255, 255);
 }
 
-inline static void _catPath(UT_String& st, const char* st2)
-{
-	if (st.size() > 0)
-	{
-		if (st[st.size() - 1] != '/')
-			st += '/';
-	}
-	else
-		st += '/';
-
-	st += st2;
-}
-
-UT_String XAP_FrameImpl::_localizeHelpUrl (bool bLocal, const char * pathBeforeLang, 
-										   const char * pathAfterLang)
-{
-	XAP_App* pApp = m_pFrame->getApp();
-
-	UT_return_val_if_fail(pApp, "");
-	XAP_Prefs* pPrefs = pApp->getPrefs();
-	UT_return_val_if_fail(pPrefs, "");
-
-	const char* abiSuiteLibDir = pApp->getAbiSuiteLibDir();
-	const XML_Char* abiSuiteLocString = NULL;
-	UT_String url;
-
-	// evil...
-	pPrefs->getPrefsValue((XML_Char*)"StringSet", &abiSuiteLocString);
-
-	if (bLocal)
-	{
-		UT_String path(abiSuiteLibDir);
-		_catPath(path, pathBeforeLang);
-
-		UT_String localized_path(path);
-		_catPath(localized_path, abiSuiteLocString);
-
-		if (UT_directoryExists(localized_path.c_str()))
-		{
-			// the localised help exists, so use it
-			path = localized_path;
-		}
-		else
-		{
-			// the localised help directory does not exist, so fall back to the
-			// en-US help localtion, which should always be available
-			localized_path = path;
-			_catPath(localized_path, "en-US");
-		}
-
-		_catPath(localized_path, pathAfterLang);
-		url = "file://";
-		url += localized_path;
-	}
-	else {
-		//TODO: No one uses this, so what kind of prefix should it have?
-		url = pathBeforeLang;
-		_catPath(url, abiSuiteLocString);
-		_catPath(url, pathAfterLang);
-	}
-
-	url += ".html";
-	return url;
-}
-
-#define MAX_TITLE_LENGTH 256
 bool XAP_FrameImpl::_updateTitle()
 {
 	/*
@@ -161,11 +99,23 @@ bool XAP_FrameImpl::_updateTitle()
 		because that happens dynamically at menu pop-up time.  
 	*/
 
+	/* first try to use the metadata title as our title */
+	if (m_pFrame->m_pDoc->getMetaDataProp ("dc.title", m_pFrame->m_sTitle) && m_pFrame->m_sTitle.size()) {
+		m_pFrame->m_sNonDecoratedTitle = m_pFrame->m_sTitle;
+
+		if (m_pFrame->m_pDoc->isDirty())
+			m_pFrame->m_sTitle = "*" + m_pFrame->m_sTitle;
+
+		return true;
+	}
+	
+	/* that failed. let's use the filename instead */
+
 	const char* szName = m_pFrame->m_pDoc->getFilename();
 
 	if (szName && *szName) 
 	{
-		UT_UTF8String sUntruncatedString = szName;
+		UT_UTF8String sUntruncatedString(UT_basename(szName));
 		// WL_FIXME: we probably need a string truncation function, in the ut_utf8string class..
 		UT_UTF8Stringbuf::UTF8Iterator iter = sUntruncatedString.getIterator ();
 		iter = iter.start ();
@@ -177,9 +127,10 @@ bool XAP_FrameImpl::_updateTitle()
 	{
 		UT_ASSERT(m_pFrame->m_iUntitled);
 		const XAP_StringSet * pSS = m_pFrame->m_pApp->getStringSet();
-		m_pFrame->m_sTitle = UT_UTF8String_sprintf(m_pFrame->m_sTitle, 
-							   pSS->getValueUTF8(XAP_STRING_ID_UntitledDocument).utf8_str(), 
-							   m_pFrame->m_iUntitled);
+		UT_UTF8String s;
+		pSS->getValueUTF8(XAP_STRING_ID_UntitledDocument,s);
+		
+		m_pFrame->m_sTitle = UT_UTF8String_sprintf(m_pFrame->m_sTitle,s.utf8_str(),m_pFrame->m_iUntitled);
 	}
 
 	m_pFrame->m_sNonDecoratedTitle = m_pFrame->m_sTitle;
@@ -188,15 +139,14 @@ bool XAP_FrameImpl::_updateTitle()
 	{
 		// multiple top-level views, so append : & view number
 		UT_UTF8String sBuf;
-		UT_ASSERT(m_pFrame->m_nView < 10000);
 		UT_UTF8String_sprintf(sBuf, ":%d", m_pFrame->m_nView);
 		m_pFrame->m_sTitle += sBuf;
 	}
 
 	// only for non-untitled documents
 	if (m_pFrame->m_pDoc->isDirty())
-		m_pFrame->m_sTitle += " *";
+		m_pFrame->m_sTitle = "*" + m_pFrame->m_sTitle;
 
 	return true;
 }
-#endif
+//#endif
