@@ -181,11 +181,19 @@ fb_LineBreaker::breakParagraph(fl_BlockLayout* pBlock,
 				{
 				case FPRUN_FORCEDCOLUMNBREAK:
 				{
+				        if(pCurrentRun->getNextRun() && pCurrentRun->getNextRun()->getType() == FPRUN_ENDOFPARAGRAPH)
+					{
+				               pCurrentRun = pCurrentRun->getNextRun();
+					}
 					m_pLastRunToKeep = pCurrentRun;
 					goto done_with_run_loop;
 				}
 				case FPRUN_FORCEDPAGEBREAK:
 				{
+				        if(pCurrentRun->getNextRun() && pCurrentRun->getNextRun()->getType() == FPRUN_ENDOFPARAGRAPH)
+					{
+				               pCurrentRun = pCurrentRun->getNextRun();
+					}
 					m_pLastRunToKeep = pCurrentRun;
 					goto done_with_run_loop;
 				}
@@ -266,6 +274,8 @@ fb_LineBreaker::breakParagraph(fl_BlockLayout* pBlock,
 				case FPRUN_TEXT:
 				case FPRUN_HYPERLINK:
 				case FPRUN_DIRECTIONMARKER:
+				case FPRUN_MATH:
+				case FPRUN_EMBED:
 				{
 
 					break;
@@ -332,7 +342,7 @@ fb_LineBreaker::breakParagraph(fl_BlockLayout* pBlock,
 			fp_Line *pOldLine = pLine;
 			pLine = static_cast<fp_Line *>(pLine->getNext());
 
-			pBlock->_removeLine(pOldLine);
+			pBlock->_removeLine(pOldLine,true,true);
 		}
 
 
