@@ -201,6 +201,8 @@ public:
 	void					endUserAtomicGlob(void);
 	void                    setMarginChangeOnly(bool b);
 	bool                    isMarginChangeOnly(void) const;
+	bool                    changeObjectFormatNoUpdate(PTChangeFmt ptc ,PL_ObjectHandle odh,const XML_Char ** attributes,const XML_Char ** properties );	
+PT_AttrPropIndex            getAPIFromSOH(PL_ObjectHandle odh);	
 	bool					insertObject(PT_DocPosition dpos,
 										 PTObjectType pto,
 										 const XML_Char ** attributes,
@@ -298,7 +300,8 @@ public:
 	pf_Frag *               findFragOfType(pf_Frag::PFType iType, UT_sint32 iSubtype = -1,
 										   const pf_Frag * pfStart = NULL);
 	pf_Frag *               getLastFrag() const;
-	bool                    appendBlockIfNeeded(void);
+	bool                    checkForSuspect(void);
+	bool                    repairDoc(void);
 	bool                    removeStyle(const XML_Char * name);
 	bool					tellListener(PL_Listener * pListener);
 	bool					tellListenerSubset(PL_Listener * pListener,
@@ -353,9 +356,10 @@ public:
 
 	// data items
 
-	bool					createDataItem(const char * szName, bool bBase64, const UT_ByteBuf * pByteBuf,
+	virtual bool			createDataItem(const char * szName, bool bBase64, const UT_ByteBuf * pByteBuf,
 										   const void* pToken, void ** ppHandle);
-	bool					getDataItemDataByName(const char * szName,
+	virtual bool            replaceDataItem(const char * szName, const UT_ByteBuf * pByteBuf);
+	virtual bool			getDataItemDataByName(const char * szName,
 												  const UT_ByteBuf ** ppByteBuf, const void** ppToken, void ** ppHandle) const;
 	bool					setDataItemToken(void* pHandle, void* pToken);
 	bool					getDataItemData(void * pHandle,
@@ -430,6 +434,7 @@ public:
 	bool                    isEndFrameAtPos(PT_DocPosition pos);
 	bool                    isHdrFtrAtPos(PT_DocPosition pos);
 	bool                    isSectionAtPos(PT_DocPosition pos);
+	bool                    isBlockAtPos(PT_DocPosition pos);
 
 // Table functions
 
@@ -503,7 +508,7 @@ public:
 	const PP_AttrProp *     explodeRevisions(PP_RevisionAttr *& pRevisions, const PP_AttrProp * pAP,
 											 bool bShow, UT_uint32 iId, bool &bHiddenRevision) const;
 	
-	virtual void            purgeRevisionTable();
+	virtual void            purgeRevisionTable(bool bUnconditional = false);
 
 	void					notifyPieceTableChangeStart(void);
 	void					notifyPieceTableChangeEnd(void);
@@ -610,7 +615,12 @@ public:
 
 	virtual void   setAutoRevisioning(bool autorev);
 
+	virtual UT_uint32 getXID();
+	virtual UT_uint32 getTopXID() const;
+	void              fixMissingXIDs();
+	UT_uint32         getFragXIDforVersion(const pf_Frag * pf, UT_uint32 iVersion) const;
 
+	
 	UT_sint32     getNewHdrHeight(void) const
 	{ return m_iNewHdrHeight;}
 	UT_sint32     getNewFtrHeight(void) const
@@ -624,6 +634,9 @@ public:
 	bool                    purgeFmtMarks();
 
 	void                    tellPTDoNotTweakPosition(bool b);
+
+	void                    setVDNDinProgress(bool b) {m_bVDND = b;}
+	bool                    isVDNDinProgress() const {return m_bVDND;}
 	
 protected:
 	~PD_Document();
@@ -694,6 +707,10 @@ private:
 	UT_sint32               m_iNewHdrHeight;
 	UT_sint32               m_iNewFtrHeight;
 	bool                    m_bMarginChangeOnly;
+	UT_GenericVector<pf_Frag *> m_vecSuspectFrags;
+
+	bool                    m_bVDND;
+
 };
 
 #endif /* PD_DOCUMENT_H */
