@@ -39,7 +39,49 @@
 #include "pd_Document.h"
 
 
+/*!
+    XML cannot contain any control characters except \t, \n, \r, see bug 8565
+    (http://www.w3.org/TR/REC-xml/#charsets)
+    
+    This function replaces any illegal characters with '~'
+    (That choice is arbitrary, it needs to be some character that does not have a special
+    meaning in xml, xlink, etc. We could, of course, remove the character altoghether, but
+    that means moving data around.)
+*/
+static inline void s_validXML(char * s)
+{
+	if(!s)
+		return;
+	
+	while(*s)
+	{
+		if(*s < ' ' && *s >= 0 && *s != '\t' && *s != '\n' && *s != '\r')
+		{
+			*s = '~';
+		}
+		
+		++s;
+	}
+}
 
+static inline bool s_isValidXML(const char *s)
+{
+	if(!s)
+		return true;
+	
+	while(*s)
+	{
+		if(*s < ' ' && *s != '\t' && *s != '\n' && *s != '\r')
+		{
+			return false;
+		}
+		
+		++s;
+	}
+
+	return true;
+}
+	
 /****************************************************************/
 PP_AttrProp::PP_AttrProp()
 {
@@ -258,6 +300,7 @@ bool	PP_AttrProp::setAttribute(const XML_Char * szName, const XML_Char * szValue
 			if (!*q)
 			{
 				free(pOrig);
+				UT_DEBUGMSG(("props: %s\n", szValue));
 				return false;
 			}
 
@@ -329,6 +372,10 @@ bool	PP_AttrProp::setAttribute(const XML_Char * szName, const XML_Char * szValue
 		UT_lowerString(copy);
 		char * szDupValue = szValue ? UT_strdup(szValue) : NULL;
 
+		// get rid of any illegal chars we might have been given
+		s_validXML(copy);
+		s_validXML(szDupValue);
+
 		const char * pEntry = m_pAttributes->pick(copy);
 
 		if(pEntry)
@@ -355,6 +402,8 @@ bool	PP_AttrProp::setAttribute(const XML_Char * szName, const XML_Char * szValue
 
 bool	PP_AttrProp::setProperty(const XML_Char * szName, const XML_Char * szValue)
 {
+	UT_return_val_if_fail( szName, false );
+	
 	if (!m_pProperties)
 	{
 		m_pProperties = new UT_GenericStringMap<PropertyPair*>(5);
@@ -371,6 +420,24 @@ bool	PP_AttrProp::setProperty(const XML_Char * szName, const XML_Char * szValue)
 	// be present
 	// 
 	//bool bRemove = (!szValue || !*szValue);
+
+	// get rid of any chars invalid in xml
+	char * szName2 = NULL;
+	if(!s_isValidXML(szName))
+	{
+		szName2 = UT_strdup(szName);
+
+		// get rid of any illegal chars we were passed
+		s_validXML(szName2);
+
+		szName = szName2;
+	}
+	
+	char * szValue2 = szValue ? UT_strdup(szValue) : NULL;
+	UT_return_val_if_fail( szName && (szValue2 || !szValue), false);
+
+	// get rid of any illegal chars we might have been given in the value
+	s_validXML(szValue2);
 	
 	const PropertyPair * pEntry = m_pProperties->pick(szName);
 	if (pEntry)
@@ -389,12 +456,16 @@ bool	PP_AttrProp::setProperty(const XML_Char * szName, const XML_Char * szValue)
 		if (p->second())
 			delete p->second();
 		delete p;
-		m_pProperties->set(szName, new PropertyPair(szValue ? UT_strdup(szValue) : NULL, NULL));
+		m_pProperties->set(szName, new PropertyPair(szValue2, NULL));
 	}
 	else
 	{
-		m_pProperties->insert(szName, new PropertyPair(szValue ? UT_strdup(szValue) : NULL, NULL));
+		m_pProperties->insert(szName, new PropertyPair(szValue2, NULL));
 	}
+
+	// free the name duplicate if necessary
+	FREEP(szName2);
+	
 	return true;
 }
 
@@ -587,6 +658,10 @@ bool PP_AttrProp::areAlreadyPresent(const XML_Char ** attributes, const XML_Char
 
 			if((!p[1] || !*p[1]) && getAttribute(p[0],szValue) && szValue && *szValue)
 				return false;
+			// the 'props' attribute has to be handled separatedly, since it is not
+			// returned using getAttribute() (it is not stored as attribute)
+			else if((!p[1] || !*p[1]) && !strcmp(p[0],"props") && hasProperties())
+				return false;
 			else if(p[1] && *p[1])
 			{
 				if (!getAttribute(p[0],szValue))
