@@ -618,6 +618,7 @@ bool pt_PieceTable::_tweakDeleteSpanOnce(PT_DocPosition & dpos1,
 		// the block we have will then be slurped into the previous
 		// section.
 		dpos1 -= pfsContainer->getLength();
+		
 		return true;
 
 	case PTX_SectionTable:
@@ -1045,6 +1046,14 @@ bool pt_PieceTable::_deleteComplexSpan(PT_DocPosition & origPos1,
 	if(pfsContainer->getStruxType() == PTX_SectionFrame)
 	{
 		bPrevWasFrame = true;
+	        if(pf_First->getType() == pf_Frag::PFT_Strux)
+		{
+		     pf_Frag_Strux * pfs = static_cast<pf_Frag_Strux *>(pf_First);
+		     if(pfs->getStruxType() == PTX_SectionTable)
+		     {
+		          bPrevWasFrame = false;
+		     }
+		}
 	}
 	if(pfsContainer->getStruxType() == PTX_SectionCell)
 	{
