@@ -54,6 +54,7 @@ class PD_Style;
 
 class ABI_EXPORT pt_PieceTable
 {
+	friend class PX_ChangeRecord;
 public:
 	pt_PieceTable(PD_Document * pDocument);
 	~pt_PieceTable();
@@ -114,10 +115,11 @@ protected:
 	void                	_realDeleteHdrFtrStrux(pf_Frag_Strux * pfs);
 
 	bool					_realChangeSpanFmt(PTChangeFmt ptc,
-										  PT_DocPosition dpos1,
-										  PT_DocPosition dpos2,
-										  const XML_Char ** attributes,
-										  const XML_Char ** properties);
+											   PT_DocPosition dpos1,
+											   PT_DocPosition dpos2,
+											   const XML_Char ** attributes,
+											   const XML_Char ** properties,
+											   bool bRevisionDelete);
 
 	bool					_realInsertStrux(PT_DocPosition dpos,
 											 PTStruxType pts,
@@ -126,14 +128,17 @@ protected:
 											 pf_Frag_Strux ** ppfs_ret);
 
 	bool					_realChangeStruxFmt(PTChangeFmt ptc,
-										   PT_DocPosition dpos1,
-										   PT_DocPosition dpos2,
-										   const XML_Char ** attributes,
-										   const XML_Char ** properties,
-										   PTStruxType pts);
+												PT_DocPosition dpos1,
+												PT_DocPosition dpos2,
+												const XML_Char ** attributes,
+												const XML_Char ** properties,
+												PTStruxType pts,
+												bool bRevisionDelete);
 
 	bool                    _realChangeStruxForLists(PL_StruxDocHandle sdh,
-												const char * pszParentID);
+													 const char * pszParentID,
+													 bool bRevisionDelete);
+	
     bool                    _realChangeSectionAttsNoUpdate(pf_Frag_Strux * pfStrux, const char * attr, const char * attvalue);
 
 	/******************************************************************
@@ -212,6 +217,8 @@ public:
 
 	bool                    changeStruxFormatNoUpdate(PTChangeFmt ptc, pf_Frag_Strux * pfs,const XML_Char ** attributes);
 
+	bool                    changeObjectFormatNoUpdate(PTChangeFmt ptc, pf_Frag_Object * pfo,const XML_Char ** attributes,const XML_Char ** properties);
+
 	bool                    changeStruxForLists(PL_StruxDocHandle sdh,
 												const char * pszParentID);
     bool                    changeSectionAttsNoUpdate(pf_Frag_Strux * pfStrux, const char * attr, const char * attvalue);
@@ -318,7 +325,7 @@ public:
 	const UT_GenericStringMap<PD_Style *> & getAllStyles()const {return m_hashStyles;}
 	bool                    isEndFootnote(pf_Frag * pf) const;
 	bool                    isFootnote(pf_Frag * pf) const;
-
+	
 	void					clearIfAtFmtMark(PT_DocPosition dpos);
 	UT_uint32               getFragNumber(pf_Frag * pFrag) const {return m_fragments.getFragNumber(pFrag);}
     pt_VarSet &             getVarSet(void) {return m_varset;};
@@ -330,6 +337,12 @@ public:
 
 	void                    setDoNotTweakPosition(bool b) {m_bDoNotTweakPosition = b;}
 
+	UT_uint32               getXID();
+	UT_uint32               getTopXID() const {return m_iXID;}
+	void                    setXIDThreshold(UT_uint32 i){m_iXID = i;}
+	void                    fixMissingXIDs();
+	void                    setCRNumber(UT_sint32 iCRNumber)
+	{ m_iCurCRNumber = iCRNumber;}
 #ifdef PT_TEST
 	UT_TestStatus			__test_VerifyCoalescedFrags(FILE * fp) const;
 	void					__dump(FILE * fp) const;
@@ -459,12 +472,15 @@ protected:
 	bool					_fmtChangeStruxWithNotify(PTChangeFmt ptc,
 													  pf_Frag_Strux * pfs,
 													  const XML_Char ** attributes,
-													  const XML_Char ** properties);
+													  const XML_Char ** properties,
+													  bool bRevisionDelete);
+	
 	bool					_fmtChangeStruxWithNotify(PTChangeFmt ptc,
 													  pf_Frag_Strux * pfs,
 													  const XML_Char ** attributes,
 													  const XML_Char ** properties,
-													  bool bDoAll);
+													  bool bDoAll,
+													  bool bRevisionDelete);
 
 	bool					_fmtChangeSpan(pf_Frag_Text * pft, UT_uint32 fragOffset, UT_uint32 length,
 										   PT_AttrPropIndex indexNewAP,
@@ -478,8 +494,9 @@ protected:
 													 const XML_Char ** properties,
 													 pf_Frag_Strux * pfs,
 													 pf_Frag ** ppfNewEnd,
-													 UT_uint32 * pfragOffsetNewEnd);
-
+													 UT_uint32 * pfragOffsetNewEnd,
+													 bool bRevisionDelete);
+	
 	bool					_fmtChangeObject(pf_Frag_Object * pfo,
 											 PT_AttrPropIndex indexNewAP,
 											 pf_Frag ** ppfNewEnd,
@@ -493,7 +510,8 @@ protected:
 													   const XML_Char ** properties,
 													   pf_Frag_Strux * pfs,
 													   pf_Frag ** ppfNewEnd,
-													   UT_uint32 * pfragOffsetNewEnd);
+													   UT_uint32 * pfragOffsetNewEnd,
+													   bool bRevisionDelete);
 
 	bool					_getStruxFromFrag(pf_Frag * pfStart, pf_Frag_Strux ** ppfs) const;
 	bool					_getStruxFromFragSkip(pf_Frag * pfStart, pf_Frag_Strux ** ppfs) const;
@@ -548,7 +566,8 @@ protected:
 										pf_Frag_Object * &pfo);
 	bool					_makeFmtMark(pf_Frag_FmtMark * &pff);
 	bool                    _makeFmtMark(pf_Frag_FmtMark * &pff, const XML_Char ** attributes);
-
+	UT_sint32               _getNextChangeRecordNumber(void)
+	{ return m_iCurCRNumber++;}
 	// implemented in pt_PT_InsertStrux.cpp
 	bool                    _translateRevisionAttribute(PP_RevisionAttr & Revisions, PT_AttrPropIndex indexAP,
 														PP_RevisionType eType,
@@ -573,6 +592,9 @@ protected:
 	UT_uint32               m_atomicGlobCount;
 	bool                    m_bDoingTheDo;
 	bool                    m_bDoNotTweakPosition;
+
+	UT_uint32               m_iXID;
+	UT_sint32               m_iCurCRNumber;
 };
 
 #endif /* PT_PIECETABLE_H */
