@@ -157,6 +157,7 @@ AP_UnixApp::AP_UnixApp(XAP_Args * pArgs, const char * szAppName)
 	  m_bSelectionInFlux(false),
 	  m_pViewSelection(0),
 	  m_cacheSelectionView(0),
+	  m_cacheDeferClear(0),
 	  m_pFrameSelection(0)
 {
 #ifndef HAVE_GNOME
@@ -1633,7 +1634,7 @@ bool AP_UnixApp::doWindowlessArgs(const AP_Args *Args)
 			PS_Graphics * pGraphics = (PS_Graphics*) XAP_App::getApp()->newGraphics(ai);
 			
 			conv.setVerbose(Args->m_iVerbose);
-			conv.print (Args->m_sFile, pGraphics);
+			conv.print (Args->m_sFile, pGraphics, Args->m_sFileExtension);
 
 			delete pGraphics;
 	    }
