@@ -24,6 +24,7 @@
 #include "ut_string.h"
 #include "ut_debugmsg.h"
 #include "fp_PageSize.h"
+#include "gr_Painter.h"
 
 #include "xap_Dialog_Id.h"
 #include "xap_DialogFactory.h"
@@ -66,10 +67,10 @@ void AP_Dialog_Columns::_createPreviewFromGC(GR_Graphics * gc,
 										   UT_uint32 width,
 										   UT_uint32 height)
 {
-	UT_ASSERT(gc);
+	UT_return_if_fail (gc);
 
 	m_pColumnsPreview = new AP_Columns_preview(gc,this);
-	UT_ASSERT(m_pColumnsPreview);
+	UT_return_if_fail (m_pColumnsPreview);
 
 	m_pColumnsPreview->setWindowSize(width, height);
 	m_pColumnsPreview->set(m_iColumns, m_bLineBetween);
@@ -112,7 +113,7 @@ const char * AP_Dialog_Columns::getSpaceAfterString(void)
 
 /*!
  * Returns the increment associated with the dimension defined in the string.
-\params const char * sz the dimensioned string.
+\param const char * sz the dimensioned string.
 \returns double -  the increment associated with the dimension in sz
 */
 double AP_Dialog_Columns::getIncrement(const char * sz)
@@ -153,7 +154,7 @@ double AP_Dialog_Columns::getIncrement(const char * sz)
 /*!
  * Sets pointer to the Current View and document. Also sets initial values
  * for space-after and max column height.
-\params XAP_Frame * pFrame - pointer to current Frame.
+\param XAP_Frame * pFrame - pointer to current Frame.
 */
 void AP_Dialog_Columns::setViewAndDoc(XAP_Frame * pFrame)
 {
@@ -304,7 +305,7 @@ double AP_Dialog_Columns::getSpaceAfterPercent(void)
 
 /*!
  * Set the member string variable m_HeightString
-\params const char * szHeight is the string containing the new value
+\param const char * szHeight is the string containing the new value
 */
 void AP_Dialog_Columns::setMaxHeight(const char * szHeight)
 {
@@ -325,7 +326,7 @@ void AP_Dialog_Columns::setMaxHeight(const char * szHeight)
 
 /*!
  * Set the member string variable m_SpaceAfterString.
-\params const char * szAfter is the string containing the new value
+\param const char * szAfter is the string containing the new value
 */
 void AP_Dialog_Columns::setSpaceAfter(const char * szAfter)
 {
@@ -347,7 +348,9 @@ void AP_Dialog_Columns::setSpaceAfter(const char * szAfter)
 
 void AP_Dialog_Columns::_drawColumnButton(GR_Graphics *gc, UT_Rect rect, UT_uint32 iColumns)
 {
-	gc->clearArea(rect.left, rect.top, rect.width, rect.height);
+	GR_Painter painter(gc);
+
+	painter.clearArea(rect.left, rect.top, rect.width, rect.height);
 
 	rect.left += gc->tdu(2);
 	rect.width -= gc->tdu(4);
@@ -358,9 +361,9 @@ void AP_Dialog_Columns::_drawColumnButton(GR_Graphics *gc, UT_Rect rect, UT_uint
 
 /*!
  * Converts the string sz into the units seleced for the ruler.
-\params XAP_Frame * pFrame defined the frame of the application
-\params const char * sz is the string containing the old value
-\params const XML_Char * pRet is the string to which the new value is copied.
+\param XAP_Frame * pFrame defined the frame of the application
+\param const char * sz is the string containing the old value
+\param const XML_Char * pRet is the string to which the new value is copied.
 */
 void AP_Dialog_Columns::_convertToPreferredUnits(XAP_Frame * pFrame,const char *sz, XML_Char * pRet)
 {
@@ -393,6 +396,8 @@ AP_Columns_preview::~AP_Columns_preview()
 
 void AP_Columns_preview::draw(void)
 {
+	GR_Painter painter(m_gc);
+
 	UT_sint32 iWidth = m_gc->tlu(getWindowWidth());
 	UT_sint32 iHeight = m_gc->tlu(getWindowHeight());
 
@@ -400,21 +405,21 @@ void AP_Columns_preview::draw(void)
 	double SpacePercent = m_pColumns->getSpaceAfterPercent();
 	UT_Rect pageRect(m_gc->tlu(5), m_gc->tlu(5), iWidth - m_gc->tlu(10), iHeight - m_gc->tlu(10));
 
-	m_gc->fillRect(GR_Graphics::CLR3D_Background, 0, 0, iWidth, iHeight);
-	m_gc->clearArea(pageRect.left, pageRect.top, pageRect.width,
+	painter.fillRect(GR_Graphics::CLR3D_Background, 0, 0, iWidth, iHeight);
+	painter.clearArea(pageRect.left, pageRect.top, pageRect.width,
 					pageRect.height);
 
 	m_gc->setLineWidth(m_gc->tlu(1));
-	m_gc->drawLine(pageRect.left, pageRect.top,
+	painter.drawLine(pageRect.left, pageRect.top,
 		       pageRect.left + pageRect.width, pageRect.top);
-	m_gc->drawLine(pageRect.left, pageRect.top,
+	painter.drawLine(pageRect.left, pageRect.top,
 		       pageRect.left, pageRect.top + pageRect.height);
 
 	m_gc->setLineWidth(m_gc->tlu(3));
-	m_gc->drawLine(pageRect.left + pageRect.width, pageRect.top + m_gc->tlu(1),
+	painter.drawLine(pageRect.left + pageRect.width, pageRect.top + m_gc->tlu(1),
 				   pageRect.left + pageRect.width,
 				   pageRect.top + pageRect.height);
-	m_gc->drawLine(pageRect.left + m_gc->tlu(1), pageRect.top + pageRect.height,
+	painter.drawLine(pageRect.left + m_gc->tlu(1), pageRect.top + pageRect.height,
 				   pageRect.left + pageRect.width,
 				   pageRect.top + pageRect.height);
 
@@ -429,6 +434,7 @@ void AP_Columns_preview::draw(void)
 
 void AP_Columns_preview_drawer::draw(GR_Graphics *gc, UT_Rect &rect, UT_sint32 iColumns, bool bLineBetween, double maxHeightPercent, double SpacePercent)
 {
+	GR_Painter painter(gc);
 
 	UT_sint32 iHalfColumnGap = gc->tlu (rect.width / gc->tlu(20));
 
@@ -468,7 +474,7 @@ void AP_Columns_preview_drawer::draw(GR_Graphics *gc, UT_Rect &rect, UT_sint32 i
 					curskip = 0;
 					y += iSpace;
 			}
-			gc->drawLine(xLeft, y, xRight, y);
+			painter.drawLine(xLeft, y, xRight, y);
 		}
 	}
 
@@ -478,7 +484,7 @@ void AP_Columns_preview_drawer::draw(GR_Graphics *gc, UT_Rect &rect, UT_sint32 i
 		for (UT_sint32 j = 2; j <= iColumns; j++)
 		{
 			UT_sint32 x = rect.left + (j-1) * rect.width / iColumns;
-			gc->drawLine(x, y_start, x, y_end);
+			painter.drawLine(x, y_start, x, y_end);
 		}
 	}
 }
