@@ -82,14 +82,14 @@ public:
 	void						StopList(void);
 	void						Apply(void);
 	void						fillDialogFromBlock(void);
-	void						fillDialogFromVector(UT_Vector * inVec);
+	void						fillDialogFromVector(UT_GenericVector<const XML_Char*> * inVec);
 	void						PopulateDialogData(void);
 	void						fillFakeLabels(void);
 	bool						isLastOnLevel(void);
 	XML_Char *					getListStyleString( UT_uint32 iListType);
 	UT_uint32					decodeListType(char * listformat);
-	UT_sint32					findVecItem(UT_Vector * v, char * key);
-	UT_sint32					findVecItem(UT_Vector * v, const char * key);
+	UT_sint32					findVecItem(UT_GenericVector<const XML_Char*> * v, char * key);
+	UT_sint32					findVecItem(UT_GenericVector<const XML_Char*> * v, const char * key);
 	void						fillUncustomizedValues(void);
 	UT_uint32					getID(void);
 	UT_uint32					getStoredID(void) { return m_iID;}
@@ -133,8 +133,8 @@ protected:
 	SET_GATHER(bisCustomized,	bool);
 	SET_GATHER(isListAtPoint,	bool);
 	SET_GATHER(bguiChanged,	    bool);
-	SET_GATHER(NewListType,	    List_Type);
-	SET_GATHER(DocListType,	    List_Type);
+	SET_GATHER(NewListType,	    FL_ListType);
+	SET_GATHER(DocListType,	    FL_ListType);
 	SET_GATHER(iLevel,	        UT_uint32);
 	SET_GATHER(pView,	        FV_View *);
 
@@ -150,8 +150,14 @@ protected:
     void copyCharToWindowName(const char* pszName) { sprintf(m_WindowName,"%s",pszName);}
     const char * getWindowName( void) { return static_cast<const char *>(m_WindowName);}  
 	AP_Lists_preview* getListsPreview() { return m_pListsPreview; }
-
-
+	void              setCurrentFold(UT_sint32 iLevel)
+		{ m_iCurrentLevel = iLevel;}
+	UT_sint32         getCurrentFold(void)
+		{ return m_iCurrentLevel;}
+	virtual void      setFoldLevelInGUI(void) = 0;
+	virtual bool      isPageLists(void) = 0;
+	void              setFoldingLevelChanged(bool b)
+	  { m_bFoldingLevelChanged = b;}
 private:
 
 
@@ -170,7 +176,7 @@ private:
 	bool					m_previousListExistsAtPoint;
 	UT_UCSChar				m_curListLabel[100];
 	UT_UCSChar				m_newListLabel[100];
-	List_Type				m_NewListType;
+	FL_ListType				m_NewListType;
 	XML_Char				m_pszDelim[80];
 	XML_Char				m_pszDecimal[80];
 	XML_Char				m_pszFont[80];
@@ -187,7 +193,7 @@ private:
 	UT_uint32				m_curListLevel;
 	UT_uint32				m_newListLevel;
 	UT_uint32				m_iID;
-	List_Type				m_DocListType;
+	FL_ListType				m_DocListType;
 
 	bool					m_bStartList;
 
@@ -206,8 +212,10 @@ private:
 	PD_Document *			m_pFakeDoc;
 	bool					m_bDirty;
 	bool					m_bIsModal;
+	UT_sint32               m_iCurrentLevel;
 	UT_Vector				m_OutProps;
 	UT_String				m_Output[5];
+	bool                                    m_bFoldingLevelChanged;
 };
 
 
