@@ -26,12 +26,10 @@
 #include "ap_Dialog_MarkRevisions.h"
 #include "ap_Strings.h"
 
-#include <fribidi.h>
-
 AP_Dialog_MarkRevisions::AP_Dialog_MarkRevisions(XAP_DialogFactory * pDlgFactory,
 					   XAP_Dialog_Id id)
   : XAP_Dialog_NonPersistent(pDlgFactory,id, "interface/dialogmarkrevisions"), m_answer(a_CANCEL),
-		m_pDoc(NULL), m_pComment2(NULL),m_pRev(NULL)
+		m_pDoc(NULL), m_pComment2(NULL),m_pRev(NULL),m_bForceNew(false)
 {
 	m_pSS = XAP_App::getApp()->getStringSet();
 }
@@ -72,7 +70,7 @@ char * AP_Dialog_MarkRevisions::getRadio1Label()
 {
 	_initRevision();
 
-	if(!m_pRev)
+	if(!m_pRev || m_bForceNew)
 		return NULL;
 
 	UT_return_val_if_fail(m_pSS,NULL);
@@ -97,7 +95,7 @@ char * AP_Dialog_MarkRevisions::getComment1()
 {
 	_initRevision();
 
-	if(!m_pRev)
+	if(!m_pRev || m_bForceNew)
 		return NULL;
 
 	bool bFree = false;
@@ -110,26 +108,17 @@ char * AP_Dialog_MarkRevisions::getComment1()
 	// now we run this string through fribidi
 	if(XAP_App::getApp()->theOSHasBidiSupport() == XAP_App::BIDI_SUPPORT_NONE)
 	{
-		FriBidiChar *fbdStr = (FriBidiChar *)pC;
-		FriBidiChar *fbdStr2 = 0;
+		UT_UCS4Char *pStr2 = 0;
 		UT_uint32 iLen = UT_UCS4_strlen(pC);
 
-		fbdStr2  = (FriBidiChar *)UT_calloc( iLen + 1, sizeof(FriBidiChar));
-		UT_return_val_if_fail(fbdStr2,NULL);
+		pStr2  = (UT_UCS4Char *)UT_calloc( iLen + 1, sizeof(UT_UCS4Char));
+		UT_return_val_if_fail(pStr2,NULL);
 		bFree = true;
 
-		FriBidiCharType fbdDomDir = fribidi_get_type(fbdStr[0]);
+		UT_BidiCharType iDomDir = UT_bidiGetCharType(pC[0]);
 
-		fribidi_log2vis (		/* input */
-						 fbdStr,
-						 iLen,
-						 &fbdDomDir,
-						 /* output */
-						 fbdStr2,
-						 NULL,
-						 NULL,
-						 NULL);
-		pC = (const UT_UCS4Char *) fbdStr2;
+		UT_bidiReorderString(pC, iLen, iDomDir, pStr2);
+		pC = pStr2;
 
 	}
 
@@ -184,7 +173,8 @@ void AP_Dialog_MarkRevisions::addRevision()
 	if(m_pRev)
 		iId = m_pRev->getId() + 1;
 
-	m_pDoc->addRevision(iId,m_pComment2, UT_UCS4_strlen(m_pComment2));
+	time_t tStart = time(NULL);
+	m_pDoc->addRevision(iId,m_pComment2, UT_UCS4_strlen(m_pComment2), tStart, 0);
 	m_pRev = NULL;
 }
 
