@@ -98,7 +98,8 @@ AP_Dialog_Spell::~AP_Dialog_Spell(void)
 
 	DELETEP(m_pPreserver);
 
-	UT_HASH_PURGEDATA(UT_UCSChar*,m_pChangeAll, free);
+	m_pChangeAll->freeData();
+//	UT_HASH_PURGEDATA(UT_UCSChar*,m_pChangeAll, free);
 	DELETEP(m_pChangeAll);
 	DELETEP(m_pIgnoreAll);
 	DELETEP(m_pWordIterator);
@@ -112,7 +113,7 @@ void AP_Dialog_Spell::_purgeSuggestions(void)
 
 	for (UT_uint32 i = 0; i < m_Suggestions->getItemCount(); i++)
 	{
-		UT_UCSChar * sug = static_cast<UT_UCSChar *>(m_Suggestions->getNthItem(i));
+		UT_UCS4Char * sug = m_Suggestions->getNthItem(i);
 		if (sug)
 			free(sug);
 	}
@@ -122,7 +123,7 @@ void AP_Dialog_Spell::_purgeSuggestions(void)
 
 void AP_Dialog_Spell::runModal(XAP_Frame * pFrame)
 {
-   UT_ASSERT(pFrame);
+   UT_return_if_fail (pFrame);
    m_pFrame = pFrame;
 			  
    AP_FrameData * frameData = static_cast<AP_FrameData*>(m_pFrame->getFrameData());
@@ -158,8 +159,8 @@ void AP_Dialog_Spell::runModal(XAP_Frame * pFrame)
 
    m_pWordIterator = new fl_BlockSpellIterator(m_pCurrBlock, 0);
    
-   m_pChangeAll = new UT_StringPtrMap(7); // is 7 buckets adequate? too much?
-   m_pIgnoreAll = new UT_StringPtrMap(7);
+   m_pChangeAll = new UT_GenericStringMap<UT_UCSChar*>(7); // is 7 buckets adequate? too much?
+   m_pIgnoreAll = new UT_GenericStringMap<UT_UCSChar*>(7);
 
    m_bSkipWord = false;
 }
@@ -169,20 +170,19 @@ void AP_Dialog_Spell::runModal(XAP_Frame * pFrame)
  */
 bool AP_Dialog_Spell::nextMisspelledWord(void)
 {
-   UT_ASSERT(m_pWordIterator);
-   UT_ASSERT(m_pView && m_pView->getLayout() );	
+   UT_return_val_if_fail (m_pWordIterator && m_pView && m_pView->getLayout(), false);
 
    // Makes this honor spelling prefs
    XAP_App * pApp = m_pFrame->getApp();
-   UT_ASSERT(pApp);
+   UT_return_val_if_fail (pApp, false);
    XAP_Prefs * pPrefs = pApp->getPrefs();
-   UT_ASSERT(pPrefs);
+   UT_return_val_if_fail (pPrefs, false);
    
    XAP_PrefsScheme *pPrefsScheme = pPrefs->getCurrentScheme();
-   UT_ASSERT(pPrefsScheme);		  
+   UT_return_val_if_fail (pPrefsScheme, false);		  
    
    bool b = false;
-   pPrefs->getPrefsValueBool(static_cast<XML_Char*>(AP_PREF_KEY_AutoSpellCheck), &b);
+   pPrefs->getPrefsValueBool(static_cast<const XML_Char *>(AP_PREF_KEY_AutoSpellCheck), &b);
 
 
    // Yes, I know. This is a bit anal. But it works, and I'm too tired
@@ -192,10 +192,11 @@ bool AP_Dialog_Spell::nextMisspelledWord(void)
 	   m_pWordIterator->revertToPreviousWord();
    m_bSkipWord = false;
 
+   UT_sint32 iPTLength;
    // loop until a misspelled word or end of document is hit
    for (;;) 
    {
-	   while (m_pWordIterator->nextWordForSpellChecking(m_pWord, m_iWordLength, m_iWordOffset))
+	   while (m_pWordIterator->nextWordForSpellChecking(m_pWord, m_iWordLength, m_iWordOffset, iPTLength))
 	   {
 		   // We have found a word, but if there was a selection, make
 		   // sure the word lies inside the selection (this check is
@@ -230,8 +231,7 @@ bool AP_Dialog_Spell::nextMisspelledWord(void)
 			   // try ignore all list and user dictionaries here, too
 			   XAP_App * pApp = m_pFrame->getApp();
 
-			   if (!m_pDoc->isIgnore(m_pWord, m_iWordLength) &&
-			       !_spellCheckWord(m_pWord, m_iWordLength)) 
+			   if (!_spellCheckWord(m_pWord, m_iWordLength)) 
 			   {
 				   // unknown word... update dialog
 
@@ -244,13 +244,13 @@ bool AP_Dialog_Spell::nextMisspelledWord(void)
 					_purgeSuggestions();
 
 					// create an empty vector
-					UT_ASSERT(!m_Suggestions);
+					UT_ASSERT_HARMLESS(!m_Suggestions);
 
-					m_Suggestions = new UT_Vector();
-					UT_ASSERT(m_Suggestions);
+					m_Suggestions = new UT_GenericVector<UT_UCSChar*>();
+					UT_return_val_if_fail (m_Suggestions, false);
 
 					// get suggestions from spelling engine
-					const UT_Vector *cpvEngineSuggestions;
+					const UT_GenericVector<UT_UCSChar*> *cpvEngineSuggestions;
 
 					if (checker->checkWord(m_pWord, m_iWordLength) == SpellChecker::LOOKUP_FAILED)
 					{
@@ -258,8 +258,8 @@ bool AP_Dialog_Spell::nextMisspelledWord(void)
 
 				   		for (UT_uint32 i = 0; i < cpvEngineSuggestions->getItemCount(); ++i)
 						{
-							const UT_UCSChar *sug = reinterpret_cast<const UT_UCSChar *>(cpvEngineSuggestions->getNthItem(i));
-							UT_ASSERT(sug);
+							UT_UCS4Char *sug = cpvEngineSuggestions->getNthItem(i);
+							UT_return_val_if_fail (sug, false);
 							m_Suggestions->addItem(sug);
 						}
 					}
@@ -322,7 +322,7 @@ bool AP_Dialog_Spell::nextMisspelledWord(void)
 	 
 	   // update the iterator with our new block
 	   m_pWordIterator = new fl_BlockSpellIterator(m_pCurrBlock, 0);
-	   UT_ASSERT(m_pWordIterator);
+	   UT_return_val_if_fail (m_pWordIterator, false);
    }
 }
 
@@ -340,7 +340,8 @@ bool AP_Dialog_Spell::makeWordVisible(void)
 
 bool AP_Dialog_Spell::addIgnoreAll(void)
 {
-	return m_pDoc->appendIgnore(m_pWord,m_iWordLength);
+	_getDict ()->ignoreWord(m_pWord,m_iWordLength);
+	return true;
 }
 
 void AP_Dialog_Spell::ignoreWord(void)
@@ -354,10 +355,10 @@ bool AP_Dialog_Spell::inChangeAll(void)
 {
 	UT_sint32 iLength;
 	const UT_UCSChar * bufferUnicode = m_pWordIterator->getCurrentWord(iLength);
-	UT_ASSERT(bufferUnicode);
+	UT_return_val_if_fail (bufferUnicode, false);
 	char * bufferNormal = static_cast<char *>(UT_calloc(iLength + 1, sizeof(char)));
 	UT_UCS4_strncpy_to_char(bufferNormal, bufferUnicode, iLength);
-	const void * ent = m_pChangeAll->pick(bufferNormal);
+	const UT_UCSChar * ent = m_pChangeAll->pick(bufferNormal);
 	FREEP(bufferNormal);
 
 	if (ent == NULL) 
@@ -373,7 +374,7 @@ bool AP_Dialog_Spell::addChangeAll(const UT_UCSChar * newword)
 {
 	UT_sint32 iLength;
 	const UT_UCSChar * bufferUnicode = m_pWordIterator->getCurrentWord(iLength);
-	UT_ASSERT(bufferUnicode);
+	UT_return_val_if_fail (bufferUnicode, false);
 	char * bufferNormal = static_cast<char *>(UT_calloc(iLength + 1, sizeof(char)));
 	UT_UCS4_strncpy_to_char(bufferNormal, bufferUnicode, iLength);
 
@@ -381,7 +382,7 @@ bool AP_Dialog_Spell::addChangeAll(const UT_UCSChar * newword)
    UT_UCSChar * newword2 = static_cast<UT_UCSChar*>(UT_calloc(UT_UCS4_strlen(newword) + 1, sizeof(UT_UCSChar)));
    UT_UCS4_strcpy(newword2, newword);
    
-   m_pChangeAll->insert(bufferNormal, static_cast<void *>(newword2));
+   m_pChangeAll->insert(bufferNormal, newword2);
 
    FREEP(bufferNormal);
    
