@@ -54,107 +54,6 @@
 /*****************************************************************/
 /*****************************************************************/
 
-Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Autotext)
-{
-	XAP_App * pApp = XAP_App::getApp();
-	UT_return_val_if_fail (pApp && pLabel, NULL);
-
-	const char * c = NULL;
-
-	const XAP_StringSet * pss = pApp->getStringSet();
-	static UT_UTF8String s;
-	pss->getValueUTF8(AP_STRING_ID_DLG_Spell_NoSuggestions,s);
-
-	switch (id)
-	  {
-	  case AP_MENU_ID_AUTOTEXT_ATTN_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_ATTN_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_ATTN_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_ATTN_2, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_2, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_3:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_3, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_4:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_4, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_5:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_5, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_6:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_6, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_7:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_7, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_8:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_8, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_9:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_9, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_10:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_10, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_11:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_11, s); break;
-	  case AP_MENU_ID_AUTOTEXT_CLOSING_12:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_CLOSING_12, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_MAIL_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_2, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_3:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_3, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_4:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_4, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_5:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_5, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_6:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_6, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_7:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_7, s); break;
-	  case AP_MENU_ID_AUTOTEXT_MAIL_8:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_MAIL_8, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_REFERENCE_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_REFERENCE_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_REFERENCE_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_REFERENCE_2, s); break;
-	  case AP_MENU_ID_AUTOTEXT_REFERENCE_3:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_REFERENCE_3, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_SALUTATION_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_SALUTATION_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_SALUTATION_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_SALUTATION_2, s); break;
-	  case AP_MENU_ID_AUTOTEXT_SALUTATION_3:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_SALUTATION_3, s); break;
-	  case AP_MENU_ID_AUTOTEXT_SALUTATION_4:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_SALUTATION_4, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_SUBJECT_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_SUBJECT_1, s); break;
-
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_1:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_1, s); break;
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_2:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_2, s); break;
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_3:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_3, s); break;
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_4:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_4, s); break;
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_5:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_5, s); break;
-	  case AP_MENU_ID_AUTOTEXT_EMAIL_6:
-	    pss->getValueUTF8(AP_STRING_ID_AUTOTEXT_EMAIL_6, s); break;
-
-	  default:
-	    c = "No clue"; break;
-	  }
-
-	if(!c) 	c = s.utf8_str();
-
-	return c;
-}
-
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Toolbar)
 {
 	XAP_App * pApp = XAP_App::getApp();
@@ -287,24 +186,6 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Search)
 	return buf;
 }
 
-Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_AboutOS)
-{
-	// Compute the menu label for the about OS help item.
-
-	XAP_App * pApp = XAP_App::getApp();
-	UT_return_val_if_fail (pApp && pLabel, NULL);
-
-	UT_ASSERT_HARMLESS(id == AP_MENU_ID_HELP_ABOUTOS);
-
-	const char * szFormat = pLabel->getMenuLabel();
-	static char buf[128];
-
-	const char * szAppName = pApp->getApplicationName();
-
-	sprintf(buf,szFormat,szAppName);
-	return buf;
-}
-
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Checkver)
 {
 	// Compute the menu label for the about the check version item.
@@ -788,17 +669,17 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_Changes)
 		break;
 
 	case AP_MENU_ID_TABLE_INSERT:
-		if (pView->isHdrFtrEdit() || pView->isInHdrFtr(pView->getPoint()))
+		if (pView->isHdrFtrEdit() || pView->isInHdrFtr(pView->getPoint()) || pView->isInHdrFtr(pView->getSelectionAnchor()) )
 			s = EV_MIS_Gray;
 		break;
 
 	case AP_MENU_ID_TABLE_INSERT_TABLE:
-		if (pView->isHdrFtrEdit() || pView->isInHdrFtr(pView->getPoint()))
+		if (pView->isHdrFtrEdit() || pView->isInHdrFtr(pView->getPoint()) || pView->isInHdrFtr(pView->getSelectionAnchor()) )
 			s = EV_MIS_Gray;
 		break;
 
 	case AP_MENU_ID_TABLE_INSERTTABLE:
-		if (pView->isHdrFtrEdit()  || pView->isInHdrFtr(pView->getPoint()))
+		if (pView->isHdrFtrEdit()  || pView->isInHdrFtr(pView->getPoint()) || pView->isInHdrFtr(pView->getSelectionAnchor()) )
 			s = EV_MIS_Gray;
 		break;
 
@@ -1459,6 +1340,29 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_InTable)
     return EV_MIS_Gray;
 }
 
+Defun_EV_GetMenuItemState_Fn(ap_GetState_PointInTable)
+{
+	ABIWORD_VIEW;
+	UT_return_val_if_fail (pView, EV_MIS_Gray);
+
+	if(pView->isInTable(pView->getPoint()))
+		return EV_MIS_ZERO;
+
+    return EV_MIS_Gray;
+}
+
+Defun_EV_GetMenuItemState_Fn(ap_GetState_PointOrAnchorInTable)
+{
+	ABIWORD_VIEW;
+	UT_return_val_if_fail (pView, EV_MIS_Gray);
+	bool bP = pView->isInTable(pView->getPoint());
+	bool bA = pView->isInTable(pView->getSelectionAnchor());
+	if(bP || bA)
+		return EV_MIS_ZERO;
+
+    return EV_MIS_Gray;
+}
+
 
 Defun_EV_GetMenuItemState_Fn(ap_GetState_InTableIsRepeat)
 {
@@ -1487,6 +1391,10 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_TableOK)
 	{
 		return EV_MIS_Gray;
 	}
+	else if( !pView->isSelectionEmpty() &&  pView->isInTable(pView->getPoint()) && pView->isHdrFtrEdit() )
+	{
+		return EV_MIS_Gray;
+	}
 	else if(pView->isInFootnote())
 	{
 		return EV_MIS_Gray;
@@ -1563,7 +1471,7 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_InImage)
 	if(pView->getFrameEdit()->isActive())
 	{
 	        fl_FrameLayout * pFL = pView->getFrameLayout();
-		if(pFL->getFrameType() == FL_FRAME_TEXTBOX_TYPE)
+		if(pFL && pFL->getFrameType() == FL_FRAME_TEXTBOX_TYPE)
 		{
 		        return EV_MIS_Gray;
 		}
