@@ -66,6 +66,8 @@ Defun_EV_GetMenuItemState_Fn(ap_GetState_TableOK);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_TextToTableOK);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_InTOC);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_InTable);
+Defun_EV_GetMenuItemState_Fn(ap_GetState_PointInTable);
+Defun_EV_GetMenuItemState_Fn(ap_GetState_PointOrAnchorInTable);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_InTableIsRepeat);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_InTableMerged);
 Defun_EV_GetMenuItemState_Fn(ap_GetState_InFootnote);
@@ -85,9 +87,7 @@ Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_About);
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Contents);
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Checkver);
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Search);
-Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_AboutOS);
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Index);
 Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Suggest);
-Defun_EV_GetMenuItemComputedLabel_Fn(ap_GetLabel_Autotext);
 
 #endif /* AP_MENU_FUNCTIONS_H */
