@@ -46,6 +46,9 @@
 #define AP_PREF_KEY_AutoSpellCheck					"AutoSpellCheck"			/* enable automatic spell check {0,1} */
 #define AP_PREF_DEFAULT_AutoSpellCheck				"1"
 
+#define AP_PREF_KEY_AutoGrammarCheck		    "AutoGrammarCheck"			/* enable automatic grammar check {0,1} */
+#define AP_PREF_DEFAULT_AutoGrammarCheck  		"1"
+
 #define AP_PREF_KEY_SpellCheckCaps					"SpellCheckCaps"			/* enable checking CAPITALIZED words {0,1} */
 #define AP_PREF_DEFAULT_SpellCheckCaps				"1"
 
@@ -55,12 +58,6 @@
 #define AP_PREF_KEY_SpellCheckInternet				"SpellCheckInternet"		/* enable spell checking internet names {0,1} */
 #define AP_PREF_DEFAULT_SpellCheckInternet			"1"
 
-#define AP_PREF_KEY_SpellCheckIgnoredWordsSave		"SpellCheckIgnoredWordsSave"	/* save ignored words list with doc */
-#define AP_PREF_DEFAULT_SpellCheckIgnoredWordsSave	"1"
-
-#define AP_PREF_KEY_SpellCheckIgnoredWordsLoad		"SpellCheckIgnoredWordsLoad"	/* load ignored words list with doc */
-#define AP_PREF_DEFAULT_SpellCheckIgnoredWordsLoad	"1"
-
 #define AP_PREF_KEY_SpellAutoReplace                "SpellAutoReplace" /* automatically substitute "incorrect" words with replacements */
 #define AP_PREF_DEFAULT_SpellAutoReplace            "0"
 
@@ -148,11 +145,10 @@ dcl(CloseOnLastDoc)
 dcl(DefaultSaveFormat)
 dcl(CursorBlink)
 dcl(AutoSpellCheck)
+dcl(AutoGrammarCheck)
 dcl(SpellCheckCaps)
 dcl(SpellCheckNumbers)
 dcl(SpellCheckInternet)
-dcl(SpellCheckIgnoredWordsSave)
-dcl(SpellCheckIgnoredWordsLoad)
 dcl(SpellAutoReplace)
 dcl(OptionsTabNumber)
 dcl(RulerUnits)
