@@ -185,15 +185,17 @@ dcl(DLG_FormatTOC_Level3,                 "Level 3")
 dcl(DLG_FormatTOC_Level4,                 "Level 4")
 
 /* Latex dialog */
-dcl(DLG_Latex_LatexTitle,	"Latex Equation")
+dcl(DLG_Latex_LatexTitle,	"LaTeX Equation")
+dcl(DLG_Latex_LatexEquation,	"LaTeX Equation")
+dcl(DLG_Latex_Example,		"Example:")
 
 /*Equation Menus */
 dcl(MENU_LABEL_INSERT_EQUATION,"Equation")
 dcl(MENU_LABEL_TOOLTIP_INSERT_EQUATION,"Insert Equation")
 dcl(MENU_LABEL_INSERT_EQUATION_FILE,"From File")
 dcl(MENU_LABEL_TOOLTIP_INSERT_EQUATION_FILE,"Insert MathML from a file")
-dcl(MENU_LABEL_INSERT_EQUATION_LATEX,"From Latex")
-dcl(MENU_LABEL_TOOLTIP_INSERT_EQUATION_LATEX,"Insert Equation from a Latex expression")
+dcl(MENU_LABEL_INSERT_EQUATION_LATEX,"From LaTeX")
+dcl(MENU_LABEL_TOOLTIP_INSERT_EQUATION_LATEX,"Insert Equation from a LaTeX expression")
 
 /* Word Count dialog */
 dcl(DLG_WordCount_WordCountTitle,	"Word Count")
@@ -820,51 +822,6 @@ dcl(MSG_CHECK_PRINT_MODE,"Headers and Footers can only be created and edited whi
 dcl(WINDOWS_NEED_UNICOWS,	"AbiWord needs the file %s.dll\nPlease download and install it from http://www.microsoft.com/msdownload/platformsdk/sdkupdate/psdkredist.htm")
 dcl(WINDOWS_COMCTL_WARNING,	"AbiWord is designed for a newer version of the system file COMCTL32.DLL\nthan the one currently on your system. (COMCTL32.DLL version 4.72 or newer)\nA solution to this problem is explained in the FAQ on the AbiSource web site\n\n\thttp://www.abisource.com\n\nYou can use the program, but the toolbar may be missing.")
 
-	 /* below are autotext defaults */
-
-	 dcl(AUTOTEXT_ATTN_1, "Attention:")
-	 dcl(AUTOTEXT_ATTN_2, "ATTN:")
-
-	 dcl(AUTOTEXT_CLOSING_1, "Best regards,")
-	 dcl(AUTOTEXT_CLOSING_2, "Best wishes,")
-	 dcl(AUTOTEXT_CLOSING_3, "Cordially,")
-	 dcl(AUTOTEXT_CLOSING_4, "Love,")
-	 dcl(AUTOTEXT_CLOSING_5, "Regards,")
-	 dcl(AUTOTEXT_CLOSING_6, "Respectfully yours,")
-	 dcl(AUTOTEXT_CLOSING_7, "Respectfully,")
-	 dcl(AUTOTEXT_CLOSING_8, "Sincerely yours,")
-	 dcl(AUTOTEXT_CLOSING_9, "Take care,")
-	 dcl(AUTOTEXT_CLOSING_10,"Thank you,")
-	 dcl(AUTOTEXT_CLOSING_11,"Thanks,")
-	 dcl(AUTOTEXT_CLOSING_12,"Yours truly,")
-
-	 dcl(AUTOTEXT_MAIL_1,"CERTIFIED MAIL")
-	 dcl(AUTOTEXT_MAIL_2,"CONFIDENTIAL")
-	 dcl(AUTOTEXT_MAIL_3,"PERSONAL")
-	 dcl(AUTOTEXT_MAIL_4,"REGISTERED MAIL")
-	 dcl(AUTOTEXT_MAIL_5,"SPECIAL DELIVERY")
-	 dcl(AUTOTEXT_MAIL_6,"VIA AIRMAIL")
-	 dcl(AUTOTEXT_MAIL_7,"VIA FACSIMILE")
-	 dcl(AUTOTEXT_MAIL_8,"VIA OVERNIGHT MAIL")
-
-	 dcl(AUTOTEXT_REFERENCE_1,"In reply to:")
-	 dcl(AUTOTEXT_REFERENCE_2,"RE:")
-	 dcl(AUTOTEXT_REFERENCE_3,"Reference:")
-
-	 dcl(AUTOTEXT_SALUTATION_1,"Dear Mom and Dad,")
-	 dcl(AUTOTEXT_SALUTATION_2,"Dear Sir or Madam:")
-	 dcl(AUTOTEXT_SALUTATION_3,"Ladies and Gentlemen:")
-	 dcl(AUTOTEXT_SALUTATION_4,"To Whom It May Concern:")
-
-	 dcl(AUTOTEXT_SUBJECT_1,"Subject")
-
-	 dcl(AUTOTEXT_EMAIL_1, "To:")
-	 dcl(AUTOTEXT_EMAIL_2, "From:")
-	 dcl(AUTOTEXT_EMAIL_3, "Subject:")
-	 dcl(AUTOTEXT_EMAIL_4, "CC:")
-	 dcl(AUTOTEXT_EMAIL_5, "BCC:")
-	 dcl(AUTOTEXT_EMAIL_6, "Fwd:")
-
 dcl(MENU_LABEL__BOGUS1__," ")
 dcl(MENU_LABEL__BOGUS2__," ")
 dcl(MENU_LABEL_OPEN_TEMPLATE,"Open Template")
@@ -896,6 +853,7 @@ dcl(MENU_LABEL_FILE_RECENT_7,"&7 %s")
 dcl(MENU_LABEL_FILE_RECENT_8,"&8 %s")
 dcl(MENU_LABEL_FILE_RECENT_9,"&9 %s")
 dcl(MENU_LABEL_FILE_REVERT,"Re&vert")
+dcl(MENU_LABEL_FILE_SAVEEMBED,"Save to file")
 dcl(MENU_LABEL_FILE_EXIT,"&Quit")
 dcl(MENU_LABEL_EDIT,"&Edit")
 dcl(MENU_LABEL_EDIT_UNDO,"&Undo")
@@ -922,6 +880,9 @@ dcl(MENU_LABEL_EDIT_EDITHEADER,"Edit Header")
 dcl(MENU_LABEL_EDIT_EDITFOOTER,"Edit Footer")
 dcl(MENU_LABEL_EDIT_REMOVEHEADER,"Remove Header")
 dcl(MENU_LABEL_EDIT_REMOVEFOOTER,"Remove Footer")
+dcl(MENU_LABEL_EDIT_CUTEMBED,"Cut Object")
+dcl(MENU_LABEL_EDIT_COPYEMBED,"Copy Object")
+dcl(MENU_LABEL_EDIT_DELETEEMBED,"Delete Object")
 dcl(MENU_LABEL_VIEW,"&View")
 dcl(MENU_LABEL_VIEW_NORMAL,"&Normal Layout")
 dcl(MENU_LABEL_VIEW_WEB,"&Web Layout")
@@ -1007,6 +968,7 @@ dcl(MENU_LABEL_FMT_DIRECTION, "D&irectional")
 dcl(MENU_LABEL_FMT_DIRECTION_DD_RTL, "RTL &Paragraph")
 dcl(MENU_LABEL_FMT_DIRECTION_DO_LTR, "&Left-to-right text")
 dcl(MENU_LABEL_FMT_DIRECTION_DO_RTL, "&Right-to-left text")
+dcl(MENU_LABEL_FMT_EMBED, "Format Object")
 dcl(MENU_LABEL_TOOLS,"&Tools")
 dcl(MENU_LABEL_TOOLS_SPELLING,"&Spelling")
 dcl(MENU_LABEL_TOOLS_SPELL,"Check &Spelling")
@@ -1113,11 +1075,9 @@ dcl(MENU_LABEL_HELP,"&Help")
 dcl(MENU_LABEL_HELP_CREDITS,"C&redits")
 dcl(MENU_LABEL_HELP_CONTENTS,"Help &Contents")
 dcl(MENU_LABEL_HELP_INDEX,"Help &Introduction")
-dcl(MENU_LABEL_HELP_CHECKVER,"Check &Version")
+dcl(MENU_LABEL_HELP_CHECKVER,"Check for &Updates")
 dcl(MENU_LABEL_HELP_SEARCH,"&Search for Help")
 dcl(MENU_LABEL_HELP_ABOUT,"&About %s")
-dcl(MENU_LABEL_HELP_ABOUTOS,"About &Open Source")
-dcl(MENU_LABEL_HELP_ABOUT_GNU,"About &GNU Free Software")
 dcl(MENU_LABEL_HELP_ABOUT_GNOMEOFFICE,"About G&NOME Office")
 dcl(MENU_LABEL_HELP_REPORT_BUG, "Report a &Bug")
 dcl(MENU_LABEL_SPELL_SUGGEST_1,"%s")
@@ -1131,50 +1091,6 @@ dcl(MENU_LABEL_SPELL_SUGGEST_8,"%s")
 dcl(MENU_LABEL_SPELL_SUGGEST_9,"%s")
 dcl(MENU_LABEL_SPELL_IGNOREALL,"&Ignore All")
 dcl(MENU_LABEL_SPELL_ADD,"&Add")
-dcl(MENU_LABEL_INSERT_AUTOTEXT,"&Autotext")
-dcl(MENU_LABEL_AUTOTEXT_ATTN,"Attention:")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING,"Closing:")
-dcl(MENU_LABEL_AUTOTEXT_MAIL,"Mail Instructions:")
-dcl(MENU_LABEL_AUTOTEXT_REFERENCE,"Reference:")
-dcl(MENU_LABEL_AUTOTEXT_SALUTATION,"Salutation:")
-dcl(MENU_LABEL_AUTOTEXT_SUBJECT,"Subject:")
-dcl(MENU_LABEL_AUTOTEXT_EMAIL,"Email:")
-dcl(MENU_LABEL_AUTOTEXT_ATTN_1,"%s")
-dcl(MENU_LABEL_AUTOTEXT_ATTN_2,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_1,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_2,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_3,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_4,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_5,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_6,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_7,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_8,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_9,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_10,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_11,"%s")
-dcl(MENU_LABEL_AUTOTEXT_CLOSING_12,"%s")
-dcl(MENU_LABEL_AUTOTEXT_MAIL_1,"%s")
-dcl(MENU_LABEL_AUTOTEXT_MAIL_2,"%s")
-dcl(MENU_LABEL_AUTOTEXT_MAIL_3,"%s")
-dcl(MENU_LABEL_AUTOTEXT_MAIL_4,"%s")
-dcl(MENU_LABEL_AUTOTEXT_MAIL_5,"%s")
-dcl(MENU_LABEL_AUTOTEXT_MAIL_6,"%s")
-dcl(MENU_LABEL_AUTOTEXT_MAIL_7,"%s")
-dcl(MENU_LABEL_AUTOTEXT_MAIL_8,"%s")
-dcl(MENU_LABEL_AUTOTEXT_REFERENCE_1,"%s")
-dcl(MENU_LABEL_AUTOTEXT_REFERENCE_2,"%s")
-dcl(MENU_LABEL_AUTOTEXT_REFERENCE_3,"%s")
-dcl(MENU_LABEL_AUTOTEXT_SALUTATION_1,"%s")
-dcl(MENU_LABEL_AUTOTEXT_SALUTATION_2,"%s")
-dcl(MENU_LABEL_AUTOTEXT_SALUTATION_3,"%s")
-dcl(MENU_LABEL_AUTOTEXT_SALUTATION_4,"%s")
-dcl(MENU_LABEL_AUTOTEXT_SUBJECT_1,"%s")
-dcl(MENU_LABEL_AUTOTEXT_EMAIL_1,"%s")
-dcl(MENU_LABEL_AUTOTEXT_EMAIL_2,"%s")
-dcl(MENU_LABEL_AUTOTEXT_EMAIL_3,"%s")
-dcl(MENU_LABEL_AUTOTEXT_EMAIL_4,"%s")
-dcl(MENU_LABEL_AUTOTEXT_EMAIL_5,"%s")
-dcl(MENU_LABEL_AUTOTEXT_EMAIL_6,"%s")
 
 dcl(MENU_STATUSLINE__BOGUS1__," ")
 dcl(MENU_STATUSLINE__BOGUS2__," ")
@@ -1208,6 +1124,7 @@ dcl(MENU_STATUSLINE_FILE_RECENT_8,"Open this document")
 dcl(MENU_STATUSLINE_FILE_RECENT_9,"Open this document")
 dcl(MENU_STATUSLINE_FILE_REVERT,"Revert the document to the last saved state")
 dcl(MENU_STATUSLINE_FILE_EXIT,"Close all windows in the application and exit")
+dcl(MENU_STATUSLINE_FILE_SAVEEMBED,"Save the Embedded Object")
 dcl(MENU_STATUSLINE_EDIT," ")
 dcl(MENU_STATUSLINE_EDIT_UNDO,"Undo editing")
 dcl(MENU_STATUSLINE_EDIT_REDO,"Redo previously undone editing")
@@ -1231,6 +1148,9 @@ dcl(MENU_STATUSLINE_EDIT_COPYIMAGE,"Save a copy of the image on the clipboard")
 dcl(MENU_STATUSLINE_EDIT_CUT_FRAME,"Copy the Text Box to the clipboard then remove it")
 dcl(MENU_STATUSLINE_EDIT_COPY_FRAME,"Copy the Text Box to the clipboard")
 dcl(MENU_STATUSLINE_EDIT_SELECT_FRAME,"Select the Text Box")
+dcl(MENU_STATUSLINE_EDIT_CUTEMBED,"Cut Embedded Object")
+dcl(MENU_STATUSLINE_EDIT_COPYEMBED,"Copy Embedded Object")
+dcl(MENU_STATUSLINE_EDIT_DELETEEMBED,"Delete Embedded Object")
 dcl(MENU_STATUSLINE_VIEW," ")
 dcl(MENU_STATUSLINE_VIEW_NORMAL,"Normal View")
 dcl(MENU_STATUSLINE_VIEW_WEB,"Web Layout")
@@ -1317,6 +1237,7 @@ dcl(MENU_STATUSLINE_FMT_DIRECTION, "Change directional properties of text")
 dcl(MENU_STATUSLINE_FMT_DIRECTION_DD_RTL, "Set dominant direction of paragraph to RTL")
 dcl(MENU_STATUSLINE_FMT_DIRECTION_DO_LTR, "Force left-to-right direction of text")
 dcl(MENU_STATUSLINE_FMT_DIRECTION_DO_RTL, "Force right-to-left direction of text")
+dcl(MENU_STATUSLINE_FMT_EMBED, "Format Embedded Object")
 dcl(MENU_STATUSLINE_TOOLS," "	)
 dcl(MENU_STATUSLINE_TOOLS_SPELLING," ")
 dcl(MENU_STATUSLINE_TOOLS_SPELL,"Check the document for incorrect spelling")
@@ -1420,11 +1341,9 @@ dcl(MENU_STATUSLINE_HELP," ")
 dcl(MENU_STATUSLINE_HELP_CREDITS,"Display Credits")
 dcl(MENU_STATUSLINE_HELP_CONTENTS,"Display Help Contents")
 dcl(MENU_STATUSLINE_HELP_INDEX,"Display Help Index")
-dcl(MENU_STATUSLINE_HELP_CHECKVER,"Display program version number")
+dcl(MENU_STATUSLINE_HELP_CHECKVER,"Check online for newer versions of AbiWord")
 dcl(MENU_STATUSLINE_HELP_SEARCH,"Search for help about...")
 dcl(MENU_STATUSLINE_HELP_ABOUT,"Display program information, version number, and copyright" )
-dcl(MENU_STATUSLINE_HELP_ABOUTOS,"Display information about Open Source")
-dcl(MENU_STATUSLINE_HELP_ABOUT_GNU,"About the GNU project")
 dcl(MENU_STATUSLINE_HELP_ABOUT_GNOMEOFFICE,"About the GNOME Office project")
 dcl(MENU_STATUSLINE_HELP_REPORT_BUG, "Report a bug and help AbiWord become a better product")
 dcl(MENU_STATUSLINE_SPELL_SUGGEST_1,"Change to this suggested spelling")
@@ -1438,50 +1357,6 @@ dcl(MENU_STATUSLINE_SPELL_SUGGEST_8,"Change to this suggested spelling")
 dcl(MENU_STATUSLINE_SPELL_SUGGEST_9,"Change to this suggested spelling")
 dcl(MENU_STATUSLINE_SPELL_IGNOREALL,"Ignore all occurrences of this word in the document")
 dcl(MENU_STATUSLINE_SPELL_ADD,"Add this word to the custom dictionary")
-dcl(MENU_STATUSLINE_INSERT_AUTOTEXT," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_ATTN," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING," " )
-dcl(MENU_STATUSLINE_AUTOTEXT_MAIL," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_REFERENCE," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_SALUTATION," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_SUBJECT," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_EMAIL," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_ATTN_1," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_ATTN_2," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_1," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_2," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_3," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_4," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_5," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_6," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_7," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_8," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_9," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_10," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_11," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_CLOSING_12," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_MAIL_1," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_MAIL_2," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_MAIL_3," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_MAIL_4," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_MAIL_5," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_MAIL_6," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_MAIL_7," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_MAIL_8," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_REFERENCE_1," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_REFERENCE_2," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_REFERENCE_3," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_SALUTATION_1," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_SALUTATION_2," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_SALUTATION_3," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_SALUTATION_4," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_SUBJECT_1," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_EMAIL_1," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_EMAIL_2," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_EMAIL_3," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_EMAIL_4," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_EMAIL_5," ")
-dcl(MENU_STATUSLINE_AUTOTEXT_EMAIL_6," ")
 dcl(MENU_STATUSLINE_FMT_IMAGE, "Resize this image")
 dcl(MENU_STATUSLINE_FMT_POSIMAGE, "Format this image")
 
