@@ -612,7 +612,9 @@ private:
 	bool ReadColourTable();
 	bool ReadFontTable();
 	bool ReadOneFontFromTable(bool bNested);
+	bool ReadFontName(UT_String sFontNames[2]);
 	bool ReadRevisionTable();
+	void setEncoding();  
 public:
 	bool HandlePicture();
 	void clearImageName(void)
@@ -898,6 +900,11 @@ private:
 	UT_BidiCharType       m_iAutoBidiOverride;
 	UT_BidiCharType       m_iBidiLastType;
 	UT_BidiCharType       m_iBidiNextType;
+
+	const char* m_szDefaultEncoding; // Document default char encoding.
+	int m_iDefaultFontNumber;        // Document default font.
+	PT_DocPosition        m_dPosBeforeFootnote;
+	bool                  m_bMovedPos;
 };
 
 #endif /* IE_IMP_RTF_H */
