@@ -24,23 +24,12 @@ FINK_LIB_DIR=/sw/lib
 EMBED_LIB_DIR=@executable_path/../Frameworks
 BUNDLE_LIB_DIR=$SYMROOT/AbiWord.app/Contents/Frameworks
 
-for arg in $@; do
-    if test "$arg" = "all"; then
-	for i in `ls $BUNDLE_LIB_DIR/*.dylib` ; do
-	    echo "Relocating $i..."
-	    linked_libs=`otool -L $i 2>/dev/null | grep $FINK_LIB_DIR | cut -d\  -f 1`
-	    for j in $linked_libs ; do
-		install_name_tool -change $j `echo $j | sed -e "s,$FINK_LIB_DIR,$EMBED_LIB_DIR,"` $i
-	    done
-	done
-	(cd $BUNDLE_LIB_DIR && rm -f libglib-2.0.0.dylib && ln -s libglib-2.0.dylib libglib-2.0.0.dylib)
-	(cd $BUNDLE_LIB_DIR && rm -f libgobject-2.0.0.dylib && ln -s libgobject-2.0.dylib libgobject-2.0.0.dylib)
-    else
-	i="$BUNDLE_LIB_DIR/$arg"
+for i in `ls $BUNDLE_LIB_DIR/*.dylib` ; do
 	echo "Relocating $i..."
 	linked_libs=`otool -L $i 2>/dev/null | grep $FINK_LIB_DIR | cut -d\  -f 1`
 	for j in $linked_libs ; do
-	    install_name_tool -change $j `echo $j | sed -e "s,$FINK_LIB_DIR,$EMBED_LIB_DIR,"` $i
-	done
-    fi
+		install_name_tool -change $j `echo $j | sed -e "s,$FINK_LIB_DIR,$EMBED_LIB_DIR,"` $i
+        done
 done
+(cd $BUNDLE_LIB_DIR && rm -f libglib-2.0.0.dylib && ln -s libglib-2.0.dylib libglib-2.0.0.dylib)
+(cd $BUNDLE_LIB_DIR && rm -f libgobject-2.0.0.dylib && ln -s libgobject-2.0.dylib libgobject-2.0.0.dylib)
