@@ -75,7 +75,7 @@
 #include <goffice/graph/gog-data-set.h>
 #include <goffice/graph/gog-object-xml.h>
 #include <goffice/data/go-data-simple.h>
-#include <goffice/utils/go-math.h>
+#include <goffice/graph/gog-renderer-gnome-print.h>
 #include <goffice/utils/format.h>
 #include <gsf/gsf-impl-utils.h>
 
@@ -91,7 +91,7 @@
 #include "ut_files.h"
 #endif
 #include "gr_UnixGraphics.h"
-
+#include "xap_UnixGnomePrintGraphics.h"
 //
 // AbiContolGui object
 //
@@ -192,8 +192,11 @@ cb_graph_dim_editor_update (GtkEntry *gee,
 	char const* str = gtk_entry_get_text (gee);
 	if (str == NULL)
 		return;
+	data = NULL;
 	switch (editor->data_type) {
 	case GOG_DATA_SCALAR:
+		if (!*str)
+			break;
 		val = g_ascii_strtod (str, &end);
 		if (*end == 0)
 			data = go_data_scalar_val_new (val);
@@ -224,8 +227,8 @@ cb_graph_dim_editor_update (GtkEntry *gee,
 
 	if (!data) {
 		/* display "Invalid Data message" */
-	}
-	gog_dataset_set_dim (editor->dataset, editor->dim_i, data, NULL);
+	} else
+		gog_dataset_set_dim (editor->dataset, editor->dim_i, data, NULL);
 }
 
 static void
@@ -727,7 +730,7 @@ AbiGOChart_FileInsert(AV_View* v, EV_EditMethodCallData *d)
 
 // Insert the object
 
-    const char* mimetypeGOChart = "application/chart+xml";
+    const char* mimetypeGOChart = "application/x-goffice-graph";
 
     const char * szProps = "embed-type: GOChart";
     UT_ByteBuf * pBuf = pImpObject->getByteBuf();
@@ -768,7 +771,7 @@ cb_update_graph (GogGraph *graph, gpointer data)
 	XAP_Frame *pFrame = XAP_App::getApp()->getLastFocussedFrame();
 	FV_View* pView = static_cast<FV_View*>(pFrame->getCurrentView());
 
-	const char* mimetypeGOChart = "application/chart+xml";
+	const char* mimetypeGOChart = "application/x-goffice-graph";
 	const char * szProps="embed-type: GOChart";
 	UT_DEBUGMSG(("Doing Embed Update from GOG callback \n"));
 	pView->cmdUpdateEmbed(&myByteBuf,mimetypeGOChart,szProps);
@@ -808,7 +811,7 @@ AbiGOChart_Create(AV_View* v, EV_EditMethodCallData *d)
 	xmlFree (mem);
 	xmlFreeDoc (xml);
 
-	const char* mimetypeGOChart = "application/chart+xml";
+	const char* mimetypeGOChart = "application/x-goffice-graph";
 	const char * szProps="embed-type: GOChart; width:2.5in; height:2.5in";
 	PT_DocPosition pos = pView->getPoint();
 	pView->cmdInsertEmbed(&myByteBuf,pView->getPoint(),mimetypeGOChart,szProps);
@@ -984,9 +987,16 @@ bool GR_GOChartManager::updatePNGSnapshot(AD_Document * pDoc, UT_Rect & rec,
 
 bool GR_GOChartManager::modify(UT_sint32 uid)
 {
+  GOChartView * pGOChartView = m_vecGOChartView.getNthItem(uid);
+  pGOChartView->modify();
   return false;
 }
 
+bool  GR_GOChartManager::isEdittable(void)
+{
+  return true;
+}
+
 void GR_GOChartManager::initializeEmbedView(UT_sint32 uid)
 {
   // FIXME write code for this.
@@ -1089,23 +1099,52 @@ GOChartView::~GOChartView(void)
 
 void GOChartView::render(UT_Rect & rec)
 {
-	GdkPixbuf *pixbuf;
-	if (rec.height != height || rec.width != width || (height == 0) || (width == 0)) 
+	if (m_pGOMan->getGraphics()->queryProperties(GR_Graphics::DGP_PAPER))
+	{
+	        XAP_UnixGnomePrintGraphics * pUGG = static_cast< XAP_UnixGnomePrintGraphics *>(m_pGOMan->getGraphics());
+		GnomePrintContext *ctx = pUGG->getGnomePrintContext();
+		UT_sint32 myWidth = pUGG->tdu(rec.width);
+		UT_sint32 myHeight = pUGG->tdu(rec.height);
+		UT_sint32 x = pUGG->tdu(rec.left);
+		UT_sint32 y = pUGG->tdu(rec.top);
+		//
+		// gnome_print places y = 0 at the bottom of the page
+		// and as y increases, it gets placed further from the bottom.
+		//
+		// This is the opposite of AbiWord where y = 0 is the top
+		// and y > 0 is further from the top.
+		//
+		// scale_ydir fixes this (and gets the landscape/portrait right 
+		// too).
+		//
+		y = pUGG->scale_ydir(y);
+		printf("print chart - x %d,y %d,width %d,height %d \n",x,y,myWidth,myHeight);
+		gnome_print_gsave (ctx);
+
+		gnome_print_translate (ctx, x, y+myHeight);
+		gog_graph_print_to_gnome_print(m_Graph,ctx,myWidth,myHeight);
+		gnome_print_grestore(ctx);
+	}
+	else 
 	{
 		GdkPixbuf *pixbuf;
-		width = rec.width;
-		height = rec.height;
-		gog_renderer_pixbuf_update (GOG_RENDERER_PIXBUF (m_Renderer), width, height, 1.0);	
-		if (m_Image)
-			delete m_Image;
-		gsize length;
-		pixbuf = gog_renderer_pixbuf_get (GOG_RENDERER_PIXBUF (m_Renderer));
-		m_Image = new GR_UnixImage(NULL, pixbuf);
-		g_object_ref(pixbuf);
-		m_Image->scaleImageTo(m_pGOMan->getGraphics(),rec);
+		if (rec.height != height || rec.width != width || (height == 0) || (width == 0)) 
+		{
+			GdkPixbuf *pixbuf;
+			width = rec.width;
+			height = rec.height;
+			gog_renderer_pixbuf_update (GOG_RENDERER_PIXBUF (m_Renderer), width, height, 1.0);	
+			if (m_Image)
+				delete m_Image;
+			gsize length;
+			pixbuf = gog_renderer_pixbuf_get (GOG_RENDERER_PIXBUF (m_Renderer));
+			m_Image = new GR_UnixImage(NULL, pixbuf);
+			g_object_ref(pixbuf);
+			m_Image->scaleImageTo(m_pGOMan->getGraphics(),rec);
+		}
+		GR_Painter painter(m_pGOMan->getGraphics());
+		painter.drawImage (m_Image, rec.left, rec.top - height);
 	}
-	GR_Painter painter(m_pGOMan->getGraphics());
-	painter.drawImage (m_Image, rec.left, rec.top - height);
 }
 
 void GOChartView::loadBuffer(UT_UTF8String & sGOChartXML)
@@ -1127,9 +1166,26 @@ void GOChartView::setDefaultFontSize( UT_sint32 iSize)
 
 }
 
+void GOChartView::modify()
+{
+    XAP_Frame *pFrame = XAP_App::getApp()->getLastFocussedFrame();
+	XAP_UnixFrameImpl *pFrameImpl = static_cast<XAP_UnixFrameImpl*>(pFrame->getFrameImpl());
+	AbiControlGUI *acg = ABI_CONTROL_GUI (g_object_new (ABI_CONTROL_GUI_TYPE, NULL));
+	
+	acg->pDoc = static_cast<PD_Document *>(pFrame->getCurrentDoc());
+
+	gog_guru (m_Graph, GOG_DATA_ALLOCATOR (acg),
+		       NULL /*GO_CMD_CONTEXT (wbcg)*/, GTK_WINDOW(pFrameImpl->getTopLevelWindow()),
+		       g_cclosure_new (G_CALLBACK (cb_update_graph), acg,
+					(GClosureNotify) graph_user_config_free_data));
+}
+
 static UT_uint32 GOChartManagerUID = 0; 
 static GR_GOChartManager  *pGOChartManager = NULL;
 
+// we use a reference-counted sniffer
+static IE_Imp_Object_Sniffer  * m_impSniffer = 0;
+
 ABI_PLUGIN_DECLARE(AbiGOChart)
 
 // -----------------------------------------------------------------------
@@ -1147,7 +1203,11 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
     mi->version = ABI_VERSION_STRING;
     mi->author = "Martin Sevior <msevior@physics.unimelb.edu.au>";
     mi->usage = "No Usage";
-    
+
+    // Add to AbiWord's plugin importers
+    m_impSniffer = new IE_Imp_Object_Sniffer();
+    IE_Imp::registerImporter (m_impSniffer);    
+
     // Add to AbiWord's plugin listeners
     XAP_App * pApp = XAP_App::getApp();	
     pGOChartManager = new GR_GOChartManager(NULL);
@@ -1159,8 +1219,13 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
 	libgoffice_init ();
 	/* Initialize plugins manager */
 	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_PLUGIN_LOADER_MODULE_TYPE);
+	/* Ensure some types are created */
+ 	GO_DATA_SCALAR_STR_TYPE;
+	GO_DATA_VECTOR_STR_TYPE;
+ 	GO_DATA_SCALAR_VAL_TYPE;
 	GO_DATA_VECTOR_VAL_TYPE;
-    return 1;
+ 	GO_DATA_MATRIX_VAL_TYPE;
+   return 1;
 }
 
 
@@ -1173,10 +1238,18 @@ int abi_plugin_unregister (XAP_ModuleInfo * mi)
     mi->author = 0;
     mi->usage = 0;
 
+    IE_Imp::unregisterImporter (m_impSniffer);
+
+    if (!m_impSniffer->unref())
+    {
+         m_impSniffer = 0;
+    }
+
     XAP_App * pApp = XAP_App::getApp();
     pApp->unRegisterEmbeddable(GOChartManagerUID);
     DELETEP(pGOChartManager);
     AbiGOChart_removeFromMenus();
+
     return 1;
 }
 
