@@ -24,6 +24,7 @@
 #define abi_plugin_supports_version abipgn_abimathview_supports_version
 #endif
 
+#include <MathView/Init.hh>
 #include <MathView/MathMLElement.hh>
 #include <MathView/ShaperManager.hh>
 #include <MathView/SpaceShaper.hh>
@@ -229,8 +230,8 @@ static void AbiMathView_addToMenus()
 
     pActionSet->addAction(myEquationAction);
 
-    XAP_Menu_Id FromFileID= pFact->addNewMenuAfter("Main",NULL,"Equation",EV_MLF_Normal);
-   UT_DEBUGMSG(("FromFile ID %d \n",FromFileID));
+    XAP_Menu_Id FromFileID= pFact->addNewMenuAfter("Main",NULL,AbiMathView_MenuLabelEquation,EV_MLF_Normal);
+    UT_DEBUGMSG(("FromFile ID %d \n",FromFileID));
 
     pFact->addNewLabel(NULL,FromFileID,AbiMathView_MenuLabelFileInsert, AbiMathView_MenuTooltipFileInsert);
 
@@ -254,7 +255,7 @@ static void AbiMathView_addToMenus()
 
     pActionSet->addAction(myFileAction);
 
-    XAP_Menu_Id FromLatexID= pFact->addNewMenuAfter("Main",NULL,"From File",EV_MLF_Normal);
+   XAP_Menu_Id FromLatexID= pFact->addNewMenuAfter("Main",NULL,AbiMathView_MenuLabelFileInsert,EV_MLF_Normal);
    UT_DEBUGMSG(("Latex ID %d \n",FromLatexID));
  
     pFact->addNewLabel(NULL,FromLatexID,AbiMathView_MenuLabelLatexInsert, AbiMathView_MenuTooltipLatexInsert);
@@ -275,7 +276,7 @@ static void AbiMathView_addToMenus()
 
     pActionSet->addAction(myLatexAction);
 
-   XAP_Menu_Id endEquationID= pFact->addNewMenuAfter("Main",NULL,"From Latex",EV_MLF_EndSubMenu);
+   XAP_Menu_Id endEquationID= pFact->addNewMenuAfter("Main",NULL,AbiMathView_MenuLabelLatexInsert,EV_MLF_EndSubMenu);
    UT_DEBUGMSG(("End Equation ID %d \n",endEquationID));
     pFact->addNewLabel(NULL,endEquationID,NULL,NULL);
 
@@ -609,14 +610,13 @@ void GR_MathManager::initialize(void)
 {
      SmartPtr<AbstractLogger> logger = Logger::create();
      m_pLogger = logger;
+     SmartPtr<Configuration> configuration = initConfiguration<libxml2_MathView>(logger, getenv("GTKMATHVIEWCONF"));
      logger->setLogLevel(LOG_INFO);
-     SmartPtr<GR_Abi_MathGraphicDevice> mathGraphicDevice = GR_Abi_MathGraphicDevice::create(logger, getGraphics());
+     SmartPtr<GR_Abi_MathGraphicDevice> mathGraphicDevice = GR_Abi_MathGraphicDevice::create(logger, configuration, getGraphics());
      m_pMathGraphicDevice = mathGraphicDevice;
      m_pAbiContext = new GR_Abi_RenderingContext(getGraphics());
-     SmartPtr<MathMLOperatorDictionary> dictionary = MathMLOperatorDictionary::create();
-     m_pOperatorDictionary = dictionary;
-     libxml2_MathView::loadOperatorDictionary(logger, dictionary,
-					      libxml2_MathView::getDefaultOperatorDictionaryPath());
+     m_pOperatorDictionary = initOperatorDictionary<libxml2_MathView>(logger, configuration);
+
      UT_sint32 i = 0;
      AbiMathViewEntityMapItem * pEnt;
      AbiMathViewEntityMapItem mi;
@@ -821,8 +821,8 @@ void GR_MathManager::setColor(UT_sint32 uid, UT_RGBColor c)
 
 void GR_MathManager::render(UT_sint32 uid, UT_Rect & rec)
 {
-  scaled x = m_pAbiContext->fromAbiX(-rec.left);
-  scaled y = m_pAbiContext->fromAbiLayoutUnits(rec.top);// should be fromAbiY()
+  scaled x = m_pAbiContext->fromAbiX(rec.left);
+  scaled y = m_pAbiContext->fromAbiLayoutUnits(-rec.top);// should be fromAbiY()
   SmartPtr<libxml2_MathView>  pMathView = m_vecMathView.getNthItem(uid);
   UT_return_if_fail(pMathView);
   pMathView->render(*m_pAbiContext, x, y);
@@ -985,7 +985,6 @@ int abi_plugin_register (XAP_ModuleInfo * mi)
     XAP_App * pApp = XAP_App::getApp();	
     pMathManager = new GR_MathManager(NULL);
     MathManagerUID = pApp->registerEmbeddable(pMathManager);
-    UT_DEBUGMSG(("Class  %x created! Listener Id %d \n",pAbiGrammar,listenerID));
    // Add to AbiWord's menus.
     AbiMathView_addToMenus();
      
