@@ -51,11 +51,11 @@ IE_Exp_DocBook_Sniffer::IE_Exp_DocBook_Sniffer (const char * name) :
 
 bool IE_Exp_DocBook_Sniffer::recognizeSuffix(const char * szSuffix)
 {
-	return (UT_stricmp(szSuffix,".dbk") == 0);
+	return (!UT_stricmp(szSuffix,".dbk") ||!UT_stricmp(szSuffix,".xml"));
 }
 
 UT_Error IE_Exp_DocBook_Sniffer::constructExporter(PD_Document * pDocument,
-													 IE_Exp ** ppie)
+						   IE_Exp ** ppie)
 {
 	IE_Exp_DocBook * p = new IE_Exp_DocBook(pDocument);
 	*ppie = p;
@@ -66,8 +66,8 @@ bool IE_Exp_DocBook_Sniffer::getDlgLabels(const char ** pszDesc,
 											const char ** pszSuffixList,
 											IEFileType * ft)
 {
-	*pszDesc = "DocBook (.dbk)";
-	*pszSuffixList = "*.dbk";
+	*pszDesc = "DocBook (.dbk, .xml)";
+	*pszSuffixList = "*.dbk; *.xml";
 	*ft = getFileType();
 	return true;
 }
@@ -695,6 +695,7 @@ void s_DocBook_Listener::_outputData(const UT_UCSChar * data, UT_uint32 length)
 			pData++;
 			break;
 
+		case UCS_VTAB:					// column break
 		case UCS_LF:					// LF -- representing a Forced-Line-Break
 			if (m_iBlockType != BT_PLAINTEXT)
 				sBuf += "<br/>";
